from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

def ActiveDiagnostic(
        camp,
        trigger_treatment_list,
        active_sensitivity=1.0,
        active_specificity=1.0,
        pos_event= 'TBTestPositive',
        treatment_fraction= 1,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TB Diagnosis Active Simple'):
    """
    ActiveDiagnostic
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    # First, get the objects
    schema_path = camp.schema_path
    intervention = s2c.get_class_with_defaults( "ActiveDiagnostic", schema_path )
    intervention.Base_Sensitivity = active_sensitivity
    intervention.Base_Specificity = active_specificity
    intervention.Treatment_Fraction = treatment_fraction
    #intervention.Days_To_Diagnosis = 0
    intervention.Event_Or_Config = 'Event' # should not be necessary
    intervention.Positive_Diagnosis_Event = camp.get_send_trigger(pos_event)

    event = common.TriggeredCampaignEvent( camp, start_day,event_name, trigger_treatment_list, [ intervention ], Nodeset_Config=utils.do_nodes( camp.schema_path, nodeIDs ), Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )
    return event

def new_intervention_as_file( camp, start_day=1, filename=None ):
    camp.add( ActiveDiagnostic( camp, trigger_treatment_list=[ "Births" ] ) )
    if filename is None:
        filename = "active_diag.json"
    camp.save( filename )
    return filename

